@@ -1,3 +1,4 @@
+import atexit
 import csv
 import logging
 import os
@@ -60,6 +61,17 @@ from . import mpi_on
 from . import mpi_size
 
 
+# Instruction to close /proc/mem at exit.
+def _close_proc_meminfo():
+    try:
+        _meminfo_file.close()
+    except Exception:
+        pass
+
+
+atexit.register(_close_proc_meminfo)
+
+
 class DeprecationError(Exception):
     pass
 
@@ -165,7 +177,240 @@ else:
 
 # --- End: if
 
-def FREE_MEMORY():
+
+def configuration(
+    atol=None,
+    rtol=None,
+    tempdir=None,
+    of_fraction=None,
+    chunksize=None,
+    collapse_parallel_mode=None,
+    free_memory_factor=None,
+    log_level=None,
+    regrid_logging=None,
+    relaxed_identities=None,
+):
+    '''View or set any number of constants in the project-wide configuration.
+
+    The full list of global constants that can be set in any combination
+    are:
+
+    * `atol`
+    * `rtol`
+    * `tempdir`
+    * `of_fraction`
+    * `chunksize`
+    * `collapse_parallel_mode`
+    * `free_memory_factor`
+    * `log_level`
+    * `regrid_logging`
+    * `relaxed_identities`
+
+    The following settings are also included in the dictionary that is
+    returned to view, but they are fixed by external factors so cannot
+    be set, hence there are no corresponding parameters:
+
+    * `total_memory`
+    * `fm_threshold`
+    * `min_total_memory`
+
+    These are all constants that apply throughout `cf`, except for in
+    specific functions only if overriden by the corresponding keyword
+    argument to that function.
+
+    The value of `None`, either taken by default or supplied as a value,
+    will result in the constant in question not being changed from the
+    current value. That is, it will have no effect.
+
+    Note that setting a constant using this function is equivalent to setting
+    it by means of a specific function of the same name, e.g. via `cf.atol`,
+    but in this case multiple constants can be set at once.
+
+    .. versionadded:: 3.6.0
+
+    .. seealso:: `atol`, `rtol`, `tempdir`, `of_fraction`, `chunksize`,
+                 `collapse_parallel_mode`, `total_memory`,
+                 `free_memory_factor`, `fm_threshold`, `min_total_memory`,
+                 `log_level`, `regrid_logging`, `relaxed_identities`
+
+    :Parameters:
+
+        atol: `float`, optional
+            The new value of absolute tolerance. The default is to not
+            change the current value.
+
+        rtol: `float`, optional
+            The new value of relative tolerance. The default is to not
+            change the current value.
+
+        tempdir: `str`, optional
+            The new directory for temporary files. Tilde expansion (an
+            initial component of ``~`` or ``~user`` is replaced by
+            that *user*'s home directory) and environment variable
+            expansion (substrings of the form ``$name`` or ``${name}``
+            are replaced by the value of environment variable *name*)
+            are applied to the new directory name.
+
+            The default is to not change the directory.
+
+        of_fraction: `float`, optional
+            The new fraction (between 0.0 and 1.0). The default is to
+            not change the current behaviour.
+
+        chunksize: `float`, optional
+            The new chunksize in bytes. The default is to not change
+            the current behaviour.
+
+        collapse_parallel_mode: `int`, optional
+            The new value (0, 1 or 2).
+
+        free_memory_factor: `float`
+            The new value of the fraction of memory kept free as a
+            temporary workspace. The default is to not change the
+            current behaviour.
+
+        log_level: `str` or `int`, optional
+            The new value of the minimal log severity level. This can
+            be specified either as a string equal (ignoring case) to
+            the named set of log levels or identifier 'DISABLE', or an
+            integer code corresponding to each of these, namely:
+
+            * ``'DISABLE'`` (``0``);
+            * ``'WARNING'`` (``1``);
+            * ``'INFO'`` (``2``);
+            * ``'DETAIL'`` (``3``);
+            * ``'DEBUG'`` (``-1``).
+
+        regrid_logging: `bool`, optional
+            The new value (either `True` to enable logging or `False`
+            to disable it). The default is to not change the current
+            behaviour.
+
+        `relaxed_identities`: `bool`, optional
+            The new value; if `True`, use 'relaxed' mode when getting a
+            construct identity. The default is to not change the current
+            value.
+
+    :Returns:
+
+        `dict`
+            The names and values of the project-wide constants prior to the
+            change, or the current names and values if no new values are
+            specified.
+
+    **Examples:**
+
+    >>> cf.configuration()  # view full global configuration of constants
+    {'rtol': 2.220446049250313e-16,
+     'atol': 2.220446049250313e-16,
+     'tempdir': '/tmp',
+     'of_fraction': 0.5,
+     'total_memory': 8287346688.0,
+     'free_memory_factor': 0.1,
+     'regrid_logging': False,
+     'collapse_parallel_mode': 0,
+     'relaxed_identities': False,
+     'log_level': 'WARNING',
+     'fm_threshold': 828734668.8000001,
+     'min_total_memory': 8287346688.0,
+     'chunksize': 82873466.88000001}
+    >>> cf.chunksize(7.5e7)  # any change to one constant...
+    82873466.88000001
+    >>> cf.configuration()['chunksize']  # ...is reflected in the configuration
+    75000000.0
+
+    >>> cf.configuration(
+    ...     of_fraction=0.7, tempdir='/usr/tmp', log_level='INFO')  # set items
+    {'rtol': 2.220446049250313e-16,
+     'atol': 2.220446049250313e-16,
+     'tempdir': '/tmp',
+     'of_fraction': 0.5,
+     'total_memory': 8287346688.0,
+     'free_memory_factor': 0.1,
+     'regrid_logging': False,
+     'collapse_parallel_mode': 0,
+     'relaxed_identities': False,
+     'log_level': 'WARNING',
+     'fm_threshold': 828734668.8000001,
+     'min_total_memory': 8287346688.0,
+     'chunksize': 75000000.0}
+    >>> cf.configuration()  # the items set have been updated accordingly
+    {'rtol': 2.220446049250313e-16,
+     'atol': 2.220446049250313e-16,
+     'tempdir': '/usr/tmp',
+     'of_fraction': 0.7,
+     'total_memory': 8287346688.0,
+     'free_memory_factor': 0.1,
+     'regrid_logging': False,
+     'collapse_parallel_mode': 0,
+     'relaxed_identities': False,
+     'log_level': 'INFO',
+     'fm_threshold': 828734668.8000001,
+     'min_total_memory': 8287346688.0,
+     'chunksize': 75000000.0}
+
+    '''
+    return _configuration(
+        new_atol=atol,
+        new_rtol=rtol,
+        new_tempdir=tempdir,
+        new_of_fraction=of_fraction,
+        new_chunksize=chunksize,
+        new_collapse_parallel_mode=collapse_parallel_mode,
+        new_free_memory_factor=free_memory_factor,
+        new_log_level=log_level,
+        new_regrid_logging=regrid_logging,
+        new_relaxed_identities=relaxed_identities,
+    )
+
+
+def _configuration(**kwargs):
+    '''Internal helper function to provide the logic for `cf.configuration`.
+
+    We delegate from the user-facing `cf.configuration` for two main reasons:
+
+    1) to avoid a name clash there between the keyword arguments and the
+    functions which they each call (e.g. `atol` and `cf.atol`) which
+    would otherwise necessitate aliasing every such function name; and
+
+    2) because the user-facing function must have the appropriate keywords
+    explicitly listed, but the very similar logic applied for each keyword
+    can be consolidated by iterating over the full dictionary of input kwargs.
+
+    '''
+    # Filter out WORKSPACE_FACTOR_{1,2} constants which are only used
+    # externally and not exposed to the user:
+    old = {name.lower(): val for name, val in CONSTANTS.items() if
+           not name.startswith('WORKSPACE_FACTOR_')}
+    # Also add rtol and atol from cfdm as they are effective constants in cf:
+    for tolerance in ('ATOL', 'RTOL'):
+        old[tolerance.lower()] = cfdm.constants.CONSTANTS[tolerance]
+
+    # Filter out 'None' kwargs from configuration() defaults. Note that this
+    # does not filter out '0' or 'True' values, which is important as the user
+    # might be trying to set those, as opposed to None emerging as default.
+    kwargs = {name: val for name, val in kwargs.items() if val is not None}
+
+    # Note values are the functions not the keyword arguments of same name:
+    reset_mapping = {
+        'new_atol': atol,
+        'new_rtol': rtol,
+        'new_tempdir': tempdir,
+        'new_of_fraction': of_fraction,
+        'new_chunksize': chunksize,
+        'new_collapse_parallel_mode': collapse_parallel_mode,
+        'new_free_memory_factor': free_memory_factor,
+        'new_log_level': log_level,
+        'new_regrid_logging': regrid_logging,
+        'new_relaxed_identities': relaxed_identities,
+    }
+    for setting_alias, new_value in kwargs.items():  # for all input kwargs...
+        reset_mapping[setting_alias](new_value)  # ...run corresponding func
+
+    return old
+
+
+def free_memory():
     '''The available physical memory.
 
     :Returns:
@@ -176,19 +421,25 @@ def FREE_MEMORY():
     **Examples:**
 
     >>> import numpy
-    >>> print('Free memory =', cf.FREE_MEMORY()/2**30, 'GiB')
+    >>> print('Free memory =', cf.free_memory()/2**30, 'GiB')
     Free memory = 88.2728042603 GiB
     >>> a = numpy.arange(10**9)
-    >>> print('Free memory =', cf.FREE_MEMORY()/2**30, 'GiB')
+    >>> print('Free memory =', cf.free_memory()/2**30, 'GiB')
     Free memory = 80.8082618713 GiB
     >>> del a
-    >>> print('Free memory =', cf.FREE_MEMORY()/2**30, 'GiB')
+    >>> print('Free memory =', cf.free_memory()/2**30, 'GiB')
     Free memory = 88.2727928162 GiB
 
     '''
     return _free_memory()
 
 
+def FREE_MEMORY(*new_free_memory):
+    '''Alias for `cf.free_memory`.
+    '''
+    return free_memory(*new_free_memory)
+
+
 def _WORKSPACE_FACTOR_1():
     '''The value of workspace factor 1 used in calculating the upper limit
     to the chunksize given the free memory factor.
@@ -215,10 +466,10 @@ def _WORKSPACE_FACTOR_2():
     return CONSTANTS['WORKSPACE_FACTOR_2']
 
 
-def FREE_MEMORY_FACTOR(*args):
+def free_memory_factor(*args):
     '''Set the fraction of memory kept free as a temporary
     workspace. Users should set the free memory factor through
-    cf.SET_PERFORMANCE so that the upper limit to the chunksize is
+    cf.set_performance so that the upper limit to the chunksize is
     recalculated appropriately. The free memory factor must be a
     sensible value between zero and one. If no arguments are passed
     the existing free memory factor is returned.
@@ -236,35 +487,75 @@ def FREE_MEMORY_FACTOR(*args):
     '''
     old = CONSTANTS['FREE_MEMORY_FACTOR']
     if args:
-        free_memory_factor = float(args[0])
+        try:
+            free_memory_factor = float(args[0])
+        except (ValueError, TypeError):
+            raise ValueError('Free memory factor must be a float')
         if free_memory_factor <= 0.0 or free_memory_factor >= 1.0:
             raise ValueError(
                 'Free memory factor must be between 0.0 and 1.0 not inclusive')
 
         CONSTANTS['FREE_MEMORY_FACTOR'] = free_memory_factor
-        CONSTANTS['FM_THRESHOLD'] = free_memory_factor * TOTAL_MEMORY()
+        CONSTANTS['FM_THRESHOLD'] = free_memory_factor * total_memory()
 
     return old
 
 
+def FREE_MEMORY_FACTOR(*new_free_memory_factor):
+    '''Alias for `cf.free_memory_factor`.
+    '''
+    return free_memory_factor(*new_free_memory_factor)
+
+
+def _cf_free_memory_factor(*new_free_memory_factor):
+    '''Internal alias for `cf.free_memory_factor`.
+
+    Used in this module to prevent a name clash with a function keyword
+    argument (corresponding to 'import X as cf_X' etc. in other modules).
+    Note we don't use FREE_MEMORY_FACTOR() as it will likely be deprecated
+    in future.
+    '''
+    return free_memory_factor(*new_free_memory_factor)
+
+
 # --------------------------------------------------------------------
 # Functions inherited from cfdm
 # --------------------------------------------------------------------
-ATOL = cfdm.ATOL
-RTOL = cfdm.RTOL
+# User-facing names:
+atol = cfdm.atol
+rtol = cfdm.rtol
 CF = cfdm.CF
+# Module-level alias to avoid name clashes with function keyword arguments
+# (corresponding to 'import atol as cf_atol' etc. in other modules)
+cf_atol = cfdm.atol
+cf_rtol = cfdm.rtol
+
+
+# Aliases (for back-compatibility etc.):
+def ATOL(*new_atol):
+    '''Alias for `cf.atol`.
+    '''
+    return atol(*new_atol)
+
+
+def RTOL(*new_rtol):
+    '''Alias for `cf.rtol`.
+    '''
+    return rtol(*new_rtol)
+
 
 _disable_logging = cfdm._disable_logging
-# We can inherit the generic logic for the cf-python LOG_LEVEL() function
-# as contained in _log_level, but can't inherit the user-facing LOG_LEVEL()
+# We can inherit the generic logic for the cf-python log_level() function
+# as contained in _log_level, but can't inherit the user-facing log_level()
 # from cfdm as it operates on cfdm's CONSTANTS dict. Define cf-python's own.
-# This also means the LOG_LEVEL dostrings are independent which is important
+# This also means the log_level dostrings are independent which is important
 # for providing module-specific documentation links and directives, etc.
 _log_level = cfdm._log_level
 _reset_log_emergence_level = cfdm._reset_log_emergence_level
+_is_valid_log_level_int = cfdm._is_valid_log_level_int
 
 
-def LOG_LEVEL(*log_level):
+def log_level(*log_level):
     '''The minimal level of seriousness of log messages which are shown.
 
     This can be adjusted to filter out potentially-useful log messages
@@ -306,22 +597,28 @@ def LOG_LEVEL(*log_level):
 
     **Examples:**
 
-    >>> LOG_LEVEL()  # get the current value
+    >>> log_level()  # get the current value
     'WARNING'
-    >>> LOG_LEVEL('INFO')  # change the value to 'INFO'
+    >>> log_level('INFO')  # change the value to 'INFO'
     'WARNING'
-    >>> LOG_LEVEL()
+    >>> log_level()
     'INFO'
-    >>> LOG_LEVEL(0)  # set to 'DISABLE' via corresponding integer
+    >>> log_level(0)  # set to 'DISABLE' via corresponding integer
     'INFO'
-    >>> LOG_LEVEL()
+    >>> log_level()
     'DISABLE'
 
     '''
     return _log_level(CONSTANTS, log_level)
 
 
-def CHUNKSIZE(*args):
+def LOG_LEVEL(*new_log_level):
+    '''Alias for `cf.log_level`.
+    '''
+    return log_level(*new_log_level)
+
+
+def chunksize(*args):
     '''Set the chunksize used by LAMA for partitioning the data
     array. This must be smaller than an upper limit determined by the
     free memory factor, which is the fraction of memory kept free as a
@@ -351,7 +648,7 @@ def CHUNKSIZE(*args):
     '''
     old = CONSTANTS['CHUNKSIZE']
     if args:
-        upper_chunksize = ((FREE_MEMORY_FACTOR() * MIN_TOTAL_MEMORY())
+        upper_chunksize = ((free_memory_factor() * min_total_memory())
                            / ((mpi_size * _WORKSPACE_FACTOR_1()) +
                               _WORKSPACE_FACTOR_2()))
         if args[0] is None:
@@ -372,7 +669,23 @@ def CHUNKSIZE(*args):
     return old
 
 
-def FM_THRESHOLD():
+def CHUNKSIZE(*new_chunksize):
+    '''Alias for `cf.chunksize`.
+    '''
+    return chunksize(*new_chunksize)
+
+
+def _cf_chunksize(*new_chunksize):
+    '''Internal alias for `cf.chunksize`.
+
+    Used in this module to prevent a name clash with a function keyword
+    argument (corresponding to 'import X as cf_X' etc. in other modules).
+    Note we don't use CHUNKSIZE() as it will likely be deprecated in future.
+    '''
+    return chunksize(*new_chunksize)
+
+
+def fm_threshold():
     '''The amount of memory which is kept free as a temporary work space.
 
     :Returns:
@@ -382,14 +695,20 @@ def FM_THRESHOLD():
 
     **Examples:**
 
-    >>> cf.FM_THRESHOLD()
+    >>> cf.fm_threshold()
     10000000000.0
 
     '''
     return CONSTANTS['FM_THRESHOLD']
 
 
-def SET_PERFORMANCE(chunksize=None, free_memory_factor=None):
+def FM_THRESHOLD(*new_fm_threshold):
+    '''Alias for `cf.fm_threshold`.
+    '''
+    return fm_threshold(*new_fm_threshold)
+
+
+def set_performance(chunksize=None, free_memory_factor=None):
     '''Tune performance of parallelisation by setting chunksize and free
     memory factor. By just providing the chunksize it can be changed
     to a smaller value than an upper limit, which is determined by the
@@ -420,36 +739,54 @@ def SET_PERFORMANCE(chunksize=None, free_memory_factor=None):
             A tuple of the previous chunksize and free_memory_factor.
 
     '''
-    old = CHUNKSIZE(), FREE_MEMORY_FACTOR()
+    old = _cf_chunksize(), _cf_free_memory_factor()
     if free_memory_factor is None:
         if chunksize is not None:
-            CHUNKSIZE(chunksize)
+            _cf_chunksize(chunksize)
     else:
-        FREE_MEMORY_FACTOR(free_memory_factor)
+        _cf_free_memory_factor(free_memory_factor)
         try:
-            CHUNKSIZE(chunksize)
+            _cf_chunksize(chunksize)
         except ValueError:
-            FREE_MEMORY_FACTOR(old[1])
+            _cf_free_memory_factor(old[1])
             raise
     # --- End: if
 
     return old
 
 
-def MIN_TOTAL_MEMORY():
+def SET_PERFORMANCE(*new_set_performance):
+    '''Alias for `cf.set_performance`.
+    '''
+    return set_performance(*new_set_performance)
+
+
+def min_total_memory():
     '''The minumum total memory across nodes.
     '''
     return CONSTANTS['MIN_TOTAL_MEMORY']
 # --- End: def
 
 
-def TOTAL_MEMORY():
+def MIN_TOTAL_MEMORY(*new_min_total_memory):
+    '''Alias for `cf.min_total_memory`.
+    '''
+    return min_total_memory(*new_min_total_memory)
+
+
+def total_memory():
     '''TODO
     '''
     return CONSTANTS['TOTAL_MEMORY']
 
 
-def TEMPDIR(*arg):
+def TOTAL_MEMORY(*new_total_memory):
+    '''Alias for `cf.total_memory`.
+    '''
+    return total_memory(*new_total_memory)
+
+
+def tempdir(*arg):
     '''The directory for internally generated temporary files.
 
     When setting the directory, it is created if the specified path
@@ -475,12 +812,12 @@ def TEMPDIR(*arg):
 
     **Examples:**
 
-    >>> cf.TEMPDIR()
+    >>> cf.tempdir()
     '/tmp'
-    >>> old = cf.TEMPDIR('/home/me/tmp')
-    >>> cf.TEMPDIR(old)
+    >>> old = cf.tempdir('/home/me/tmp')
+    >>> cf.tempdir(old)
     '/home/me/tmp'
-    >>> cf.TEMPDIR()
+    >>> cf.tempdir()
     '/tmp'
 
     '''
@@ -499,7 +836,13 @@ def TEMPDIR(*arg):
     return old
 
 
-def OF_FRACTION(*arg):
+def TEMPDIR(*new_tempdir):
+    '''Alias for `cf.tempdir`.
+    '''
+    return tempdir(*new_tempdir)
+
+
+def of_fraction(*args):
     '''The amount of concurrently open files above which files containing
     data arrays may be automatically closed.
 
@@ -526,33 +869,47 @@ def OF_FRACTION(*arg):
 
     **Examples:**
 
-    >>> cf.OF_FRACTION()
+    >>> cf.of_fraction()
     0.5
-    >>> old = cf.OF_FRACTION(0.33)
-    >>> cf.OF_FRACTION(old)
+    >>> old = cf.of_fraction(0.33)
+    >>> cf.of_fraction(old)
     0.33
-    >>> cf.OF_FRACTION()
+    >>> cf.of_fraction()
     0.5
 
     The fraction may be translated to an actual number of files as
     follows:
 
-    >>> old = cf.OF_FRACTION(0.75)
+    >>> old = cf.of_fraction(0.75)
     >>> import resource
     >>> max_open_files = resource.getrlimit(resource.RLIMIT_NOFILE)[0]
-    >>> threshold = int(max_open_files * cf.OF_FRACTION())
+    >>> threshold = int(max_open_files * cf.of_fraction())
     >>> max_open_files, threshold
     (1024, 768)
 
     '''
     old = CONSTANTS['OF_FRACTION']
-    if arg:
-        CONSTANTS['OF_FRACTION'] = arg[0]
+    if args:
+        try:
+            fraction = float(args[0])
+        except (ValueError, TypeError):
+            raise ValueError('Fraction must be a float')
+        fraction = float(args[0])
+        if fraction <= 0.0 or fraction >= 1.0:
+            raise ValueError(
+                'Fraction must be between 0.0 and 1.0 not inclusive')
+        CONSTANTS['OF_FRACTION'] = fraction
 
     return old
 
 
-def REGRID_LOGGING(*arg):
+def OF_FRACTION(*new_of_fraction):
+    '''Alias for `cf.of_fraction`.
+    '''
+    return of_fraction(*new_of_fraction)
+
+
+def regrid_logging(*arg):
     '''Whether or not to enable ESMPy logging.
 
     If it is logging is performed after every call to ESMPy.
@@ -560,8 +917,8 @@ def REGRID_LOGGING(*arg):
     :Parameters:
 
         arg: `bool`, optional
-            The new value (either True to enable logging or False to
-            disable it).  The default is to not change the current
+            The new value (either `True` to enable logging or `False`
+            to disable it). The default is to not change the current
             behaviour.
 
     :Returns:
@@ -572,11 +929,11 @@ def REGRID_LOGGING(*arg):
 
     **Examples:**
 
-    >>> cf.REGRID_LOGGING()
+    >>> cf.regrid_logging()
     False
-    >>> cf.REGRID_LOGGING(True)
+    >>> cf.regrid_logging(True)
     False
-    >>> cf.REGRID_LOGGING()
+    >>> cf.regrid_logging()
     True
 
     '''
@@ -587,7 +944,13 @@ def REGRID_LOGGING(*arg):
     return old
 
 
-def COLLAPSE_PARALLEL_MODE(*arg):
+def REGRID_LOGGING(*new_regrid_logging):
+    '''Alias for `cf.regrid_logging`.
+    '''
+    return regrid_logging(*new_regrid_logging)
+
+
+def collapse_parallel_mode(*arg):
     '''Which mode to use when collapse is run in parallel. There are three
     possible modes:
 
@@ -619,25 +982,35 @@ def COLLAPSE_PARALLEL_MODE(*arg):
 
     **Examples:**
 
-    >>> cf.COLLAPSE_PARALLEL_MODE()
+    >>> cf.collapse_parallel_mode()
     0
-    >>> cf.COLLAPSE_PARALLEL_MODE(1)
+    >>> cf.collapse_parallel_mode(1)
     0
-    >>> cf.COLLAPSE_PARALLEL_MODE()
+    >>> cf.collapse_parallel_mode()
     1
 
     '''
     old = CONSTANTS['COLLAPSE_PARALLEL_MODE']
     if arg:
-        if arg[0] not in (0, 1, 2):
-            raise ValueError('Invalid collapse parallel mode')
+        allowed_values = (0, 1, 2)
+        if arg[0] not in allowed_values:
+            raise ValueError(
+                'Invalid collapse parallel mode. Valid values are '
+                '{}'.format(allowed_values)
+            )
 
         CONSTANTS['COLLAPSE_PARALLEL_MODE'] = arg[0]
 
     return old
 
 
-def RELAXED_IDENTITIES(*arg):
+def COLLAPSE_PARALLEL_MODE(*new_collapse_parallel_mode):
+    '''Alias for `cf.collapse_parallel_mode`.
+    '''
+    return collapse_parallel_mode(*new_collapse_parallel_mode)
+
+
+def relaxed_identities(*arg):
     '''Use 'relaxed' mode when getting a construct identity.
 
     If set to True, sets ``relaxed=True`` as the default in calls to a
@@ -658,16 +1031,16 @@ def RELAXED_IDENTITIES(*arg):
 
     **Examples:**
 
-    >>> org = cf.RELAXED_IDENTITIES()
+    >>> org = cf.relaxed_identities()
     >>> org
     False
-    >>> cf.RELAXED_IDENTITIES(True)
+    >>> cf.relaxed_identities(True)
     False
-    >>> cf.RELAXED_IDENTITIES()
+    >>> cf.relaxed_identities()
     True
-    >>> cf.RELAXED_IDENTITIES(org)
+    >>> cf.relaxed_identities(org)
     True
-    >>> cf.RELAXED_IDENTITIES()
+    >>> cf.relaxed_identities()
     False
 
     '''
@@ -678,6 +1051,12 @@ def RELAXED_IDENTITIES(*arg):
     return old
 
 
+def RELAXED_IDENTITIES(*new_relaxed_identities):
+    '''Alias for `cf.relaxed_identities`.
+    '''
+    return relaxed_identities(*new_relaxed_identities)
+
+
 # def IGNORE_IDENTITIES(*arg):
 #     '''TODO
 #
@@ -768,7 +1147,7 @@ if _linux:
 
     The threshold is defined as a fraction of the maximum possible number
     of concurrently open files (an operating system dependent amount). The
-    fraction is retrieved and set with the `OF_FRACTION` function.
+    fraction is retrieved and set with the `of_fraction` function.
 
     .. seealso:: `cf.close_files`, `cf.close_one_file`,
                  `cf.open_files`
@@ -784,17 +1163,17 @@ if _linux:
     In this example, the number of open files is 75% of the maximum
     possible number of concurrently open files:
 
-    >>> cf.OF_FRACTION()
+    >>> cf.of_fraction()
     0.5
     >>> cf.open_files_threshold_exceeded()
     True
-    >>> cf.OF_FRACTION(0.9)
+    >>> cf.of_fraction(0.9)
     >>> cf.open_files_threshold_exceeded()
     False
 
         '''
         return (len(listdir(_fd_dir)) >
-                _max_number_of_open_files * OF_FRACTION())
+                _max_number_of_open_files * of_fraction())
 
 
 else:
@@ -809,7 +1188,7 @@ else:
 
     The threshold is defined as a fraction of the maximum possible number
     of concurrently open files (an operating system dependent amount). The
-    fraction is retrieved and set with the `OF_FRACTION` function.
+    fraction is retrieved and set with the `of_fraction` function.
 
     .. seealso:: `cf.close_files`, `cf.close_one_file`,
                  `cf.open_files`
@@ -825,17 +1204,17 @@ else:
     In this example, the number of open files is 75% of the maximum
     possible number of concurrently open files:
 
-    >>> cf.OF_FRACTION()
+    >>> cf.of_fraction()
     0.5
     >>> cf.open_files_threshold_exceeded()
     True
-    >>> cf.OF_FRACTION(0.9)
+    >>> cf.of_fraction(0.9)
     >>> cf.open_files_threshold_exceeded()
     False
 
         '''
         return (len(_process.open_files()) >
-                _max_number_of_open_files * OF_FRACTION())
+                _max_number_of_open_files * of_fraction())
 
 
 # --- End: if
@@ -1034,11 +1413,11 @@ def _numpy_allclose(a, b, rtol=None, atol=None, verbose=None):
 
         atol : float, optional
             The absolute tolerance for all numerical comparisons, By
-            default the value returned by the `ATOL` function is used.
+            default the value returned by the `atol` function is used.
 
         rtol : float, optional
             The relative tolerance for all numerical comparisons, By
-            default the value returned by the `RTOL` function is used.
+            default the value returned by the `rtol` function is used.
 
     :Returns:
 
@@ -1124,11 +1503,11 @@ def _numpy_isclose(a, b, rtol=None, atol=None):
 
         atol: `float`, optional
             The absolute tolerance for all numerical comparisons, By
-            default the value returned by the `ATOL` function is used.
+            default the value returned by the `atol` function is used.
 
         rtol: `float`, optional
             The relative tolerance for all numerical comparisons, By
-            default the value returned by the `RTOL` function is used.
+            default the value returned by the `rtol` function is used.
 
     :Returns:
 
@@ -1383,7 +1762,7 @@ def parse_indices(shape, indices, cyclic=False, reverse=False,
                             )
 
                         if reverse and step < 0:
-                            # The array is strictly monotoniticall
+                            # The array is strictly monotonically
                             # decreasing, so reverse it so that it's
                             # strictly monotonically increasing.  Make
                             # a note that this dimension will need
@@ -1548,9 +1927,9 @@ def equals(x, y, rtol=None, atol=None, ignore_data_type=False,
     '''
     '''
     if rtol is None:
-        rtol = RTOL()
+        rtol = cf_rtol()
     if atol is None:
-        atol = ATOL()
+        atol = cf_atol()
 
     return _equals(x, y, rtol=rtol, atol=atol,
                    ignore_data_type=ignore_data_type,
@@ -1571,11 +1950,11 @@ def equivalent(x, y, rtol=None, atol=None, traceback=False):
 
         atol : float, optional
             The absolute tolerance for all numerical comparisons, By
-            default the value returned by the `ATOL` function is used.
+            default the value returned by the `atol` function is used.
 
         rtol : float, optional
             The relative tolerance for all numerical comparisons, By
-            default the value returned by the `RTOL` function is used.
+            default the value returned by the `rtol` function is used.
 
         traceback : bool, optional
             If True then print a traceback highlighting where the two
@@ -1614,9 +1993,9 @@ def equivalent(x, y, rtol=None, atol=None, traceback=False):
     '''
 
     if rtol is None:
-        rtol = RTOL()
+        rtol = cf_rtol()
     if atol is None:
-        atol = ATOL()
+        atol = cf_atol()
 
     eq = getattr(x, 'equivalent', None)
     if callable(eq):
@@ -2204,11 +2583,11 @@ def allclose(x, y, rtol=None, atol=None):
 
         atol: `float`, optional
             The absolute tolerance for all numerical comparisons, By
-            default the value returned by the `ATOL` function is used.
+            default the value returned by the `atol` function is used.
 
         rtol: `float`, optional
             The relative tolerance for all numerical comparisons, By
-            default the value returned by the `RTOL` function is used.
+            default the value returned by the `rtol` function is used.
 
     :Returns:
 
@@ -2219,9 +2598,9 @@ def allclose(x, y, rtol=None, atol=None):
 
     '''
     if rtol is None:
-        rtol = RTOL()
+        rtol = cf_rtol()
     if atol is None:
-        atol = ATOL()
+        atol = cf_atol()
 
     allclose = getattr(x, 'allclose', None)
     if callable(allclose):
@@ -2374,7 +2753,7 @@ def _section(x, axes=None, data=False, stop=None, chunks=False,
         # array.
         #
         # I.e. factor = 1/(the number of words per chunk)
-        factor = (x.dtype.itemsize + 1.0)/CHUNKSIZE()
+        factor = (x.dtype.itemsize + 1.0)/chunksize()
 
         # n_chunks = number of equal sized bits the partition needs to
         #            be split up into so that each bit's size is less
