@@ -2,4 +2,4 @@ from .properties           import Properties
 from .propertiesdata       import (PropertiesData,
                                    Subspace)
 from .propertiesdatabounds import PropertiesDataBounds
-#from .coordinate           import Coordinate
+from .coordinate           import Coordinate
