@@ -30,15 +30,17 @@ def write(fields, filename, fmt='NETCDF4', overwrite=True,
           fletcher32=False, shuffle=True, reference_datetime=None,
           verbose=None, cfa_options=None, mode='w', single=None,
           double=None, variable_attributes=None, string=True,
-          warn_valid=True, HDF_chunksizes=None, no_shuffle=None,
-          unlimited=None):
+          warn_valid=True, group=True, HDF_chunksizes=None,
+          no_shuffle=None, unlimited=None):
     '''Write field constructs to a netCDF file.
 
+
     **File format**
 
     See the *fmt* parameter for details on which output netCDF file
     formats are supported.
 
+
     **NetCDF variable and dimension names**
 
     These names are stored within constructs read a from dataset, or
@@ -59,6 +61,7 @@ def write(fields, filename, fmt='NETCDF4', overwrite=True,
     `~cf.DomainAxis.nc_set_dimension` and
     `~cf.DomainAxis.nc_del_dimension`.
 
+
     **NetCDF attributes**
 
     Field construct properties may be written as netCDF global
@@ -66,6 +69,7 @@ def write(fields, filename, fmt='NETCDF4', overwrite=True,
     *file_descriptors*, *global_attributes* and *variable_attributes*
     parameters for details.
 
+
     **External variables**
 
     Metadata constructs marked as external are omitted from the file
@@ -73,6 +77,7 @@ def write(fields, filename, fmt='NETCDF4', overwrite=True,
     attribute. However, omitted constructs may be written to an
     external file (see the *external* parameter for details).
 
+
     **NetCDF unlimited dimensions**
 
     Domain axis constructs that correspond to NetCDF unlimited
@@ -81,6 +86,17 @@ def write(fields, filename, fmt='NETCDF4', overwrite=True,
     `~cf.DomainAxis.nc_set_unlimited` methods of a domain axis
     construct.
 
+
+    **NetCDF hierarchical groups**
+
+    Hierarchical groups in CF provide a mechanism to structure
+    variables within netCDF4 datasets with well defined rules for
+    resolving references to out-of-group netCDF variables and
+    dimensions. The group structure defined by a field construct's
+    netCDF interface will, by default, be recreated in the output
+    dataset. See the *group* parameter for details.
+
+
     **NetCDF4 HDF chunk sizes**
 
     HDF5 chunksizes may be set on contruct's data. See the
@@ -445,19 +461,29 @@ def write(fields, filename, fmt='NETCDF4', overwrite=True,
             maximum string length, regardless of the selected output
             file format.
 
-        verbose: `int` or `None`, optional
-            If an integer from ``0`` to ``3``, corresponding to increasing
-            verbosity (else ``-1`` as a special case of maximal and extreme
-            verbosity), set for the duration of the method call (only) as
-            the minimum severity level cut-off of displayed log messages,
-            regardless of the global configured `cf.LOG_LEVEL`.
+        verbose: `int` or `str` or `None`, optional
+            If an integer from ``-1`` to ``3``, or an equivalent string
+            equal ignoring case to one of:
 
-            Else, if `None` (the default value), log messages will be
-            filtered out, or otherwise, according to the value of the
-            `cf.LOG_LEVEL` setting.
+            * ``'DISABLE'`` (``0``)
+            * ``'WARNING'`` (``1``)
+            * ``'INFO'`` (``2``)
+            * ``'DETAIL'`` (``3``)
+            * ``'DEBUG'`` (``-1``)
 
-            Overall, the higher a non-negative integer that is set (up to
-            a maximum of ``3``) the more description that is printed to
+            set for the duration of the method call only as the minimum
+            cut-off for the verboseness level of displayed output (log)
+            messages, regardless of the globally-configured `cf.log_level`.
+            Note that increasing numerical value corresponds to increasing
+            verbosity, with the exception of ``-1`` as a special case of
+            maximal and extreme verbosity.
+
+            Otherwise, if `None` (the default value), output messages will
+            be shown according to the value of the `cf.log_level` setting.
+
+            Overall, the higher a non-negative integer or equivalent string
+            that is set (up to a maximum of ``3``/``'DETAIL'``) for
+            increasing verbosity, the more description that is printed to
             convey how constructs map to output netCDF dimensions, variables
             and attributes.
 
@@ -482,6 +508,15 @@ def write(fields, filename, fmt='NETCDF4', overwrite=True,
 
             .. versionadded:: 3.4.0
 
+        group: `bool`, optional
+            If False then create a "flat" netCDF file, i.e. one with
+            only the root group, regardless of any group structure
+            specified by the field constructs. By default any groups
+            defined by the netCDF interface of the field constucts and
+            its components will be created and populated.
+
+            .. versionadded:: 3.6.0
+
         HDF_chunksizes: deprecated at version 3.0.0
             HDF chunk sizes may be set for individual constructs prior
             to writing, instead. See `cf.Data.nc_set_hdf5_chunksizes`.
@@ -619,7 +654,7 @@ def write(fields, filename, fmt='NETCDF4', overwrite=True,
                      endian=endian, compress=compress,
                      shuffle=shuffle, fletcher32=fletcher32,
                      verbose=verbose, string=string,
-                     warn_valid=warn_valid,
+                     warn_valid=warn_valid, group=group,
                      extra_write_vars=extra_write_vars)
     # --- End: if
 
