@@ -133,46 +133,48 @@ class DecoratorsTest(unittest.TestCase):
             # outside it or, it retains the verbosity attribute value set
             # for the previous loop (0, i.e disable, so nothing emerges!)
             test_class = dummyClass()
-            cf.LOG_LEVEL(level)  # reset to level
+            cf.log_level(level)  # reset to level
 
-            # Default verbose(=None) cases: LOG_LEVEL should determine output
-            with self.assertLogs(level=cf.LOG_LEVEL()) as catch:
+            # Default verbose(=None) cases: log_level should determine output
+            with self.assertLogs(level=cf.log_level()) as catch:
                 test_class.decorated_logging_func()
 
                 for msg in log_message:
-                    # LOG_LEVEL should prevent messages less severe appearing:
+                    # log_level should prevent messages less severe appearing:
                     if levels.index(level) >= log_message.index(msg):
                         self.assertIn(msg, catch.output)
                     else:  # less severe, should be effectively filtered out
                         self.assertNotIn(msg, catch.output)
 
-            # Cases where verbose is set; value should override LOG_LEVEL...
+            # Cases where verbose is set; value should override log_level...
 
             # Highest verbosity case (note -1 == 'DEBUG', highest verbosity):
-            # all messages should appear, regardless of global LOG_LEVEL:
-            test_class.verbose = -1
-            with self.assertLogs(level=cf.LOG_LEVEL()) as catch:
-                test_class.decorated_logging_func()
-                for msg in log_message:
-                    self.assertIn(msg, catch.output)
+            # all messages should appear, regardless of global log_level:
+            for attr in (-1, 'DEBUG', 'debug', 'Debug', 'DeBuG'):
+                test_class.verbose = attr
+                with self.assertLogs(level=cf.log_level()) as catch:
+                    test_class.decorated_logging_func()
+                    for msg in log_message:
+                        self.assertIn(msg, catch.output)
 
             # Lowest verbosity case ('WARNING' / 1) excluding special case of
             # 'DISABLE' (see note above): only warning messages should appear,
-            # regardless of global LOG_LEVEL value set:
-            test_class.verbose = 1
-            with self.assertLogs(level=cf.LOG_LEVEL()) as catch:
-                test_class.decorated_logging_func()
-                for msg in log_message:
-                    if msg.split(":")[0] == 'WARNING':
-                        self.assertIn(msg, catch.output)
-                    else:
-                        self.assertNotIn(msg, catch.output)
+            # regardless of global log_level value set:
+            for attr in (1, 'WARNING', 'warning', 'Warning', 'WaRning'):
+                test_class.verbose = attr
+                with self.assertLogs(level=cf.log_level()) as catch:
+                    test_class.decorated_logging_func()
+                    for msg in log_message:
+                        if msg.split(":")[0] == 'WARNING':
+                            self.assertIn(msg, catch.output)
+                        else:
+                            self.assertNotIn(msg, catch.output)
 
             # Boolean cases for testing backwards compatibility...
 
             # ... verbose=2 should be equivalent to verbose=3 now:
             test_class.verbose = True
-            with self.assertLogs(level=cf.LOG_LEVEL()) as catch:
+            with self.assertLogs(level=cf.log_level()) as catch:
                 test_class.decorated_logging_func()
                 for msg in log_message:
                     if msg.split(":")[0] == 'DEBUG':
@@ -184,18 +186,21 @@ class DecoratorsTest(unittest.TestCase):
             # test along with 'DISABLE' special case below...
 
             # Special 'DISABLE' (0) case: note this needs to be last as we
-            # reset the LOG_LEVEL to it but need to use 'NOTSET' for the
+            # reset the log_level to it but need to use 'NOTSET' for the
             # assertLogs level, which sends all log messages through:
-            test_class.verbose = 0
-            with self.assertLogs(level='NOTSET') as catch:
-                # Note get 'AssertionError' if don't log anything at all, so
-                # avoid this and allow check for disabled logging, first log
-                # something then disable and check nothing else emerges:
-                logger.info("Purely to keep 'assertLog' happy: see comment!")
-                cf.LOG_LEVEL('DISABLE')
-                test_class.decorated_logging_func()
-                for msg in log_message:  # nothing else should be logged
-                    self.assertNotIn(msg, catch.output)
+            for attr in (0, 'DISABLE', 'disable', 'Disable', 'DisAblE'):
+                test_class.verbose = attr
+                with self.assertLogs(level='NOTSET') as catch:
+                    # Note: get 'AssertionError' if don't log anything at all,
+                    # so to avoid this and allow check for disabled logging,
+                    # first log something then disable and check that no other
+                    # messages emerge:
+                    logger.info(
+                        "Purely to keep 'assertLog' happy: see comment!")
+                    cf.log_level('DISABLE')
+                    test_class.decorated_logging_func()
+                    for msg in log_message:  # nothing else should be logged
+                        self.assertNotIn(msg, catch.output)
 
             # verbose=0 should be equivalent in behaviour to verbose=0
             test_class.verbose = False
